@@ -1,5 +1,5 @@
 --
--- (C) 2013-16 - ntop.org
+-- (C) 2013-17 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -9,16 +9,17 @@ require "lua_utils"
 
 sendHTTPHeader('application/json')
 
-if(_GET["csrf"] ~= nil) then
+if _GET["ifid"] ~= nil then
+   interface.select(_GET["ifid"])
+end
 
-interface.select(ifname)
-if((_GET["hostIP"] ~= nil) and (_GET["hostIP"] ~= "")) then
+if((_GET["ip"] ~= nil) and (_GET["ip"] ~= "")) then
    vlan = 0
-   if ((_GET["hostVlan"] ~= nil) and (_GET["hostIP"] ~= "")) then
-      vlan = tonumber(_GET["hostVlan"])
+   if ((_GET["vlan"] ~= nil) and (_GET["vlan"] ~= "")) then
+      vlan = tonumber(_GET["vlan"])
    end
   
-   host = interface.getHostInfo(_GET["hostIP"], vlan)
+   host = interface.getHostInfo(_GET["ip"], vlan)
 
    if(host == nil) then 
       print("{ }\n")
@@ -28,7 +29,8 @@ if((_GET["hostIP"] ~= nil) and (_GET["hostIP"] ~= "")) then
 else
    -- All hosts
    
-   hosts_stats,total = aggregateHostsStats(interface.getHostsInfo())
+   hosts_stats = interface.getHostsInfo()
+   hosts_stats = hosts_stats["hosts"]
    num = 0
    print("[\n")
 
@@ -49,4 +51,3 @@ else
 
    print("\n]\n")
 end
-end
\ No newline at end of file
