@@ -1,5 +1,5 @@
 --
--- (C) 2013-16 - ntop.org
+-- (C) 2013-17 - ntop.org
 --
 
 dirs = ntop.getDirs()
@@ -7,7 +7,7 @@ package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
 
 require "lua_utils"
 
-sendHTTPHeader('text/html; charset=iso-8859-1')
+sendHTTPContentTypeHeader('text/html')
 
 
 ntop.dumpFile(dirs.installdir .. "/httpdocs/inc/header.inc")
@@ -15,12 +15,9 @@ active_page = "hosts"
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
 interface.select(ifname)
-hosts_stats,total = aggregateHostsStats(interface.getHostsInfo())
-num = 0
-for key, value in pairs(hosts_stats) do
-    num = num + 1
-end
-
+local hosts_stats = interface.getHostsInfo()
+local num = hosts_stats["numHosts"]
+hosts_stats = hosts_stats["hosts"]
 
 if(num > 0) then
 print [[
@@ -30,9 +27,14 @@ print [[
    </style>
 
 <hr>
-<h2>Hosts GeoMap</H2>
+<h2>]] print(i18n("geo_map.hosts_geomap")) print[[</H2>
+
+]]
+
+addGoogleMapsScript()
+
+print[[
 
-    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false"></script>
     <script src="]] print(ntop.getHttpPrefix()) print [[/js/markerclusterer.js"></script>
 <div class="container-fluid">
   <div class="row-fluid">
@@ -58,7 +60,7 @@ var url_prefix = "]] print(ntop.getHttpPrefix()) print [[";
 </html>
 ]]
 else 
-   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> No results found</div>")
+   print("<div class=\"alert alert-danger\"><img src=".. ntop.getHttpPrefix() .. "/img/warning.png> " .. i18n("no_results_found") .. "</div>")
 end
 
-dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
\ No newline at end of file
+dofile(dirs.installdir .. "/scripts/lua/inc/footer.lua")
